Breadcrumb class
A horizontal breadcrumb trail for communicating navigational hierarchy.
The last item in items is treated as the current (non-tappable) page. All preceding items are tappable and call onItemTapped with their index.
Breadcrumb(
items: const ['Home', 'Settings', 'Profile'],
onItemTapped: (i) => _navigateTo(i),
)
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- Breadcrumb
- Available extensions
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
items
→ List<
String> -
Ordered labels from root to current page.
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- onItemTapped → void Function(int index)
-
Called with the index of a tapped ancestor item.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- separatorIcon → IconData?
-
Icon to display between the items. If
null, defaults to theforwardIconsupplied byThemeData.iconography.final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< Breadcrumb> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
-
withBrightness(
double amount) → Widget -
Available on Widget, provided by the BrightnessFilter extension
Applies a multiplicative brightness factor to this widget.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited