MenuItem class sealed

A sealed base class for items that can appear in a MenuButton dropdown.

Use MenuOption for actionable entries and MenuDivider to insert a visual separator between groups of options.

Implementers

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited