SideNavDestination<T> class

A tappable navigation destination in a SideNav.

Inheritance
Annotations

Constructors

SideNavDestination({required T value, required Widget icon, required Widget label, Badge? badge})
Creates a side nav destination.

Properties

badge Badge?
An optional Badge at the trailing edge (expanded only).
final
hashCode int
The hash code for this object.
no setterinherited
icon Widget
The icon shown in collapsed and expanded states.
final
label Widget
The label shown when expanded.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value → T
The value identifying this destination.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited