BadgeSize enum
Controls the height and font size of a Badge.
Values
- small → const BadgeSize
-
20 px tall; 11 sp text.
const BadgeSize(height: 20, fontSize: 11, horizontalPadding: 8) - medium → const BadgeSize
-
24 px tall; 12 sp text (default).
const BadgeSize(height: 24, fontSize: 12, horizontalPadding: 10) - large → const BadgeSize
-
28 px tall; 13 sp text.
const BadgeSize(height: 28, fontSize: 13, horizontalPadding: 12)
Properties
- fontSize → double
-
The font size of the label.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → double
-
The total height of the badge in logical pixels.
final
- horizontalPadding → double
-
Horizontal padding inside the pill.
final
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited