Snackbar class
A brief overlay notification typically shown at the bottom of the screen.
Display via SnackbarHandler or the context.showSnackbar
extension rather than placing directly in the widget tree.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- Snackbar
- Available extensions
Constructors
- Snackbar({required Widget message, SnackbarTone tone = SnackbarTone.dark, SnackbarAction? action, Widget? icon, Key? key})
-
Creates a snackbar.
tonedefaults to SnackbarTone.dark.const - Snackbar.danger({required Widget message, Widget? icon, SnackbarAction? action, Key? key})
-
Creates a red error snackbar.
const
- Snackbar.success({required Widget message, Widget? icon, SnackbarAction? action, Key? key})
-
Creates a green success snackbar.
const
Properties
- action → SnackbarAction?
-
An optional action shown at the trailing edge.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- icon → Widget?
-
An optional icon at the leading edge.
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- message → Widget
-
The main message content, typically a Text widget.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tone → SnackbarTone
-
The colour style.
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
-
withBrightness(
double amount) → Widget -
Available on Widget, provided by the BrightnessFilter extension
Applies a multiplicative brightness factor to this widget.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited